@@ -135,10 +135,12 @@ def test_image_filename_defaults():
     nt.assert_is_none(img._repr_jpeg_())
 
 def _get_inline_config():
-    from ipykernel.pylab.config import InlineBackend
+    from matplotlib_inline.config import InlineBackend
     return InlineBackend.instance()
 
-@dec.skip_without('matplotlib')
+
+@dec.skip_without("ipykernel")
+@dec.skip_without("matplotlib")
 def test_set_matplotlib_close():
     cfg = _get_inline_config()
     cfg.close_figures = False
@@ -173,13 +175,15 @@ def test_set_matplotlib_formats():
             else:
                 nt.assert_not_in(Figure, f)
 
-@dec.skip_without('matplotlib')
+
+@dec.skip_without("ipykernel")
+@dec.skip_without("matplotlib")
 def test_set_matplotlib_formats_kwargs():
     from matplotlib.figure import Figure
     ip = get_ipython()
     cfg = _get_inline_config()
     cfg.print_figure_kwargs.update(dict(foo='bar'))
-    kwargs = dict(quality=10)
+    kwargs = dict(dpi=150)
     display.set_matplotlib_formats('png', **kwargs)
     formatter = ip.display_formatter.formatters['image/png']
     f = formatter.lookup_by_type(Figure)
